@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -18,9 +18,6 @@
 
 #include <Main.hpp>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-# include <EventFilterWorkarounds.hpp>
-#endif
 #include <PanGestureEventFilter.hpp>
 #include <ScreenSaver.hpp>
 #include <MainWidget.hpp>
@@ -34,6 +31,7 @@
 #include <IPC.hpp>
 
 #include <QCommandLineParser>
+#include <QVersionNumber>
 #include <QApplication>
 #include <QImageReader>
 #include <QTreeWidget>
@@ -51,8 +49,9 @@
 #if defined(CHECK_FOR_EGL) || defined(Q_OS_MACOS)
     #include <QSurfaceFormat>
 #endif
-#ifdef Q_OS_ANDROID
-    #include <QtCore/private/qandroidextras_p.h>
+
+#ifdef Q_OS_WIN
+# include <lmcons.h>
 #endif
 
 #include <clocale>
@@ -73,7 +72,14 @@ QMPlay2GUIClass &QMPlay2GUIClass::instance()
 QString QMPlay2GUIClass::getPipe()
 {
 #if defined Q_OS_WIN
-    return "\\\\.\\pipe\\QMPlay2";
+    QString userNameSuffix;
+
+    wchar_t userName[UNLEN + 1];
+    DWORD bufferSize = UNLEN + 1;
+    if (GetUserNameW(userName, &bufferSize) && bufferSize > 1)
+        userNameSuffix = QStringLiteral(".") + QString::fromWCharArray(userName, bufferSize - 1);
+
+    return QStringLiteral("\\\\.\\pipe\\QMPlay2") + userNameSuffix;
 #elif defined Q_OS_MACOS
     return "/tmp/QMPlay2." + QString(getenv("USER"));
 #else
@@ -145,12 +151,19 @@ void QMPlay2GUIClass::loadIcons()
 {
     deleteIcons();
 
-    // QtSvg doesn't support effects. This workaround generates drop shadow effect similar to
-    // drop shadow in SVG file. Remove / modify this workaround if QMPlay2 SVG icon changes!
-    const QSize size(128, 128);
-    const QPixmap pixmap = QIcon(":/QMPlay2.svgz").pixmap(size);
-    const qreal sizeRatio = (((qreal)pixmap.size().width()  / (qreal)size.width()) + ((qreal)pixmap.size().height() / (qreal)size.height())) / 2.0;
-    qmplay2Icon = new QIcon(Functions::applyDropShadow(pixmap, 10.0 * sizeRatio, QPointF(3.0 * sizeRatio, 3.0 * sizeRatio), QColor(0, 0, 0, 127)));
+    if (QVersionNumber::fromString(qVersion()) >= QVersionNumber(6, 7, 0))
+    {
+        qmplay2Icon = new QIcon(":/QMPlay2.svgz");
+    }
+    else
+    {
+        // QtSvg doesn't support effects. This workaround generates drop shadow effect similar to
+        // drop shadow in SVG file. Remove / modify this workaround if QMPlay2 SVG icon changes!
+        const QSize size(128, 128);
+        const QPixmap pixmap = QIcon(":/QMPlay2.svgz").pixmap(size);
+        const qreal sizeRatio = (((qreal)pixmap.size().width()  / (qreal)size.width()) + ((qreal)pixmap.size().height() / (qreal)size.height())) / 2.0;
+        qmplay2Icon = new QIcon(Functions::applyDropShadow(pixmap, 10.0 * sizeRatio, QPointF(3.0 * sizeRatio, 3.0 * sizeRatio), QColor(0, 0, 0, 127)));
+    }
 
     groupIcon = new QIcon(getIconFromTheme("folder-orange"));
     mediaIcon = new QIcon(getIconFromTheme("applications-multimedia"));
@@ -195,17 +208,21 @@ void QMPlay2GUIClass::restoreGeometry(const QString &pth, QWidget *w, const int
     const auto screen = window->screen();
     Q_ASSERT(screen);
 
-    const auto screenSize = screen->size();
-
     const QRect geo = settings->getRect(pth);
     if (geo.isValid())
     {
+        const auto screenGeo = screen->virtualGeometry();
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        if (const auto newScreen = screen->virtualSiblingAt(geo.center()); newScreen && newScreen != screen)
+            w->setScreen(newScreen);
+#endif
         w->setGeometry(geo);
-        if (!screen->geometry().contains(w->pos()))
-            w->move(screenSize.width() / 2 - w->width() / 2, screenSize.height() / 2 - w->height() / 2);
+        if (!screenGeo.contains(w->pos()))
+            w->move(screenGeo.width() / 2 - w->width() / 2, screenGeo.height() / 2 - w->height() / 2);
     }
     else
     {
+        const auto screenSize = screen->size();
         const QSize defaultSize = screen->availableGeometry().size() * defaultSizePercent / 100;
         w->move(screenSize.width() / 2 - defaultSize.width() / 2, screenSize.height() / 2 - defaultSize.height() / 2);
         w->resize(defaultSize);
@@ -217,11 +234,11 @@ void QMPlay2GUIClass::updateInDockW()
     qobject_cast<MainWidget *>(mainW)->videoDock->updateIDW();
 }
 
-const QWidget *QMPlay2GUIClass::getVideoDock() const
+QWidget *QMPlay2GUIClass::getVideoDock() const
 {
     return qobject_cast<MainWidget *>(mainW)->videoDock;
 }
-const QWidget *QMPlay2GUIClass::getMainWindow() const
+QWidget *QMPlay2GUIClass::getMainWindow() const
 {
     return mainW;
 }
@@ -257,6 +274,8 @@ static QCommandLineParser *createCmdParser(bool descriptions)
         QT_TRANSLATE_NOOP("Help", "Play previous entry on playlist."),
         QT_TRANSLATE_NOOP("Help", "Terminate the application."),
         QT_TRANSLATE_NOOP("Help", "Display this help."),
+        QT_TRANSLATE_NOOP("Help", "Remove specified <url> from playlist."),
+        QT_TRANSLATE_NOOP("Help", "Start in tray."),
     };
 
     const auto maybeGetTranslatedText = [&](const char *text) {
@@ -271,6 +290,7 @@ static QCommandLineParser *createCmdParser(bool descriptions)
         {"open", maybeGetTranslatedText(translations[0]), "url"},
         {"opennew", maybeGetTranslatedText(translations[1]), "url"},
         {"enqueue", maybeGetTranslatedText(translations[2]), "url"},
+        {"remove", maybeGetTranslatedText(translations[17]), "url"},
         {"profile", maybeGetTranslatedText(translations[3]), "profile name"},
         {"noplay", maybeGetTranslatedText(translations[4])},
         {"toggle", maybeGetTranslatedText(translations[5])},
@@ -284,6 +304,9 @@ static QCommandLineParser *createCmdParser(bool descriptions)
         {"next", maybeGetTranslatedText(translations[13])},
         {"prev", maybeGetTranslatedText(translations[14])},
         {"quit", maybeGetTranslatedText(translations[15])},
+#if !(defined Q_OS_MACOS || defined Q_OS_ANDROID)
+        {"tray", maybeGetTranslatedText(translations[18])},
+#endif
         {{"h", "help"}, maybeGetTranslatedText(translations[16])},
     });
 
@@ -366,10 +389,9 @@ static inline void exitProcedure()
 
 #ifndef Q_OS_WIN
     #include <csetjmp>
-    static jmp_buf env;
-    static bool qAppOK;
-    static bool canDeleteApp = true;
+    static jmp_buf g_env;
 #endif
+static bool g_qAppOK = false;
 
 static inline void forceKill()
 {
@@ -413,13 +435,12 @@ static void signal_handler(int s)
             break;
         case SIGABRT:
 #ifndef Q_OS_WIN
-            if (!qAppOK && g_useGui)
+            if (!g_qAppOK && qApp)
             {
-                canDeleteApp = g_useGui = false;
-                longjmp(env, 1);
+                longjmp(g_env, 1);
             }
 #endif
-            QMPlay2Core.log("QMPlay2 has been aborted (SIGABRT)", ErrorLog | AddTimeToLog | (qApp ? SaveLog : DontShowInGUI));
+            QMPlay2Core.log("QMPlay2 has been aborted (SIGABRT)", ErrorLog | AddTimeToLog | (g_qAppOK ? SaveLog : DontShowInGUI));
             callDefaultSignalHandler(s);
             break;
         case SIGILL:
@@ -439,7 +460,7 @@ static void signal_handler(int s)
     }
     if (crashSignal)
     {
-        QMPlay2Core.log(QString("QMPlay2 crashed (%1)").arg(crashSignal), ErrorLog | AddTimeToLog | (qApp ? SaveLog : DontShowInGUI));
+        QMPlay2Core.log(QString("QMPlay2 crashed (%1)").arg(crashSignal), ErrorLog | AddTimeToLog | (g_qAppOK ? SaveLog : DontShowInGUI));
         callDefaultSignalHandler(s);
     }
 }
@@ -477,8 +498,15 @@ static QtMessageHandler g_defaultMsgHandler = nullptr;
 static QMutex g_messageHandlerMutex;
 static void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &message)
 {
+    if (qstrcmp(context.category, "qt.qpa.wayland") == 0 && message.endsWith(QStringLiteral("Please fix the transient parent of the popup.")))
+        return;
+
+    bool skip = false;
+    if (message.startsWith(QStringLiteral("load glyph failed")))
+        skip = true;
+
     bool qmplay2Log = false;
-    if (QCoreApplication::instance())
+    if (!skip && QCoreApplication::instance())
     {
         // Use QMPlay2 logger only when we have a "QApplication" instance (we're still executing "main()"),
         // so any static data including "QSystemLocaleSingleton" and "QMPlay2CoreClass" are still valid.
@@ -634,19 +662,19 @@ int main(int argc, char *argv[])
     qputenv("QT_ANDROID_MINIMUM_MOUSE_DOUBLE_CLICK_DISTANCE", "1000"); // Otherwise double-tap doesn't work in Qt6
 #endif
     qputenv("QT_QPA_UPDATE_IDLE_TIME", "0");
+    qputenv("QT_WAYLAND_FRAME_CALLBACK_TIMEOUT", "0");
 
 #ifdef Q_OS_HAIKU
     setenv("HOME", "/boot/home", 1);
 #endif
 
 #ifdef Q_OS_ANDROID
-    QGuiApplication::setAttribute(Qt::AA_DontUseNativeDialogs);
     QGuiApplication::setAttribute(Qt::AA_DontUseNativeMenuBar); // Doesn't work in Qt6 (bug)
-    QtAndroidPrivate::requestPermission("android.permission.READ_EXTERNAL_STORAGE").result();
-    QtAndroidPrivate::requestPermission("android.permission.WRITE_EXTERNAL_STORAGE").result();
 #endif
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 #ifndef USE_OPENGL
     QGuiApplication::setAttribute(Qt::AA_ForceRasterWidgets);
 #endif
@@ -658,22 +686,28 @@ int main(int argc, char *argv[])
 #endif
 
 #ifndef Q_OS_WIN
-    if (!setjmp(env))
+    if (!setjmp(g_env))
 #endif
-    new QApplication(argc, argv);
-
-    // Qt sets this to system locale. Mesa Radeon VA-API driver lowers the image quality
-    // on some locales in some cases. Reset it for all platforms for consistency.
-    std::setlocale(LC_NUMERIC, "C");
+    {
+        new QApplication(argc, argv);
 
+        // Workaround for some libraries (e.g. AVFilter uses comma as filter separator).
+        std::setlocale(LC_NUMERIC, "C");
+    }
 #ifndef Q_OS_WIN
-    qAppOK = true;
+    else
+    {
+        new QCoreApplication(argc, argv);
+        g_useGui = false;
+    }
 #endif
     QCoreApplication::setApplicationName("QMPlay2");
 
     QMPlay2GUIClass &qmplay2Gui = QMPlay2GUI; //Create "QMPlay2GUI" instance
     g_defaultMsgHandler = qInstallMessageHandler(messageHandler);
 
+    g_qAppOK = true;
+
     QCommandLineParser *parser = createCmdParser(false);
     parser->setSingleDashWordOptionMode(QCommandLineParser::ParseAsLongOptions);
     parser->process(*qApp);
@@ -682,6 +716,24 @@ int main(int argc, char *argv[])
     QString cmdLineProfile = parser->value("profile");
     delete parser;
 
+    bool createPpipeInvoked = false;
+
+    auto createPipe = [&] {
+        Q_ASSERT(!qmplay2Gui.pipe);
+
+        createPpipeInvoked = true;
+
+        qmplay2Gui.pipe = std::make_unique<IPCServer>(qmplay2Gui.getPipe());
+        if (!qmplay2Gui.pipe->listen())
+        {
+            qmplay2Gui.pipe.reset();
+            return false;
+        }
+        return true;
+    };
+
+    bool startInvisible = false;
+
     if (!help)
     {
         bool useSocket = true;
@@ -692,11 +744,16 @@ int main(int argc, char *argv[])
             {
                 argument.first = "open";
                 useSocket = false;
-                break;
             }
+#if !(defined Q_OS_MACOS || defined Q_OS_ANDROID)
+            else if (argument.first == "tray")
+            {
+                startInvisible = true;
+            }
+#endif
         }
 
-        if (useSocket)
+        if (!createPipe() && useSocket)
         {
             IPCSocket socket(qmplay2Gui.getPipe());
             if (socket.open(IPCSocket::WriteOnly))
@@ -710,16 +767,14 @@ int main(int argc, char *argv[])
             {
                 QFile::remove(qmplay2Gui.getPipe());
                 arguments.append({"noplay", QString()});
+                createPpipeInvoked = false;
             }
 #endif
         }
 
         if (!g_useGui)
         {
-#ifndef Q_OS_WIN
-            if (canDeleteApp)
-#endif
-                delete qApp;
+            delete qApp;
             return 0;
         }
     }
@@ -772,7 +827,9 @@ int main(int argc, char *argv[])
     qRegisterMetaType<AVRational>("AVRational");
     qRegisterMetaType<Demuxer *>("Demuxer*");
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+#endif
     QApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
 
     QDir::setCurrent(QCoreApplication::applicationDirPath()); //Is it really needed?
@@ -781,9 +838,6 @@ int main(int argc, char *argv[])
     {
         qmplay2Gui.screenSaver = g_screenSaver = new ScreenSaver;
         QApplication::setQuitOnLastWindowClosed(false);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        qApp->installEventFilter(new EventFilterWorkarounds(qApp));
-#endif
         PanGestureEventFilter::install();
 #ifdef Q_OS_WIN
         auto font = QGuiApplication::font();
@@ -839,6 +893,8 @@ int main(int argc, char *argv[])
             settings.set("VolumeR", vol);
             settings.remove("Volume");
         }
+        if (settings.contains("UrlPos", true))
+            settings.remove("UrlPos");
 
         qmplay2Gui.loadIcons();
         {
@@ -847,17 +903,8 @@ int main(int argc, char *argv[])
                 QMessageBox::warning(nullptr, QString(), QObject::tr("QtSvg icon engine plugin doesn't exist.\nQMPlay2 will not scale up icons!"));
         }
 
-        qmplay2Gui.pipe = new IPCServer(qmplay2Gui.getPipe());
-        if
-        (
-#ifdef Q_OS_WIN
-            WaitNamedPipeW((const wchar_t *)qmplay2Gui.getPipe().utf16(), NMPWAIT_USE_DEFAULT_WAIT) ||
-#endif
-            !qmplay2Gui.pipe->listen()
-        )
+        if ((createPpipeInvoked && !qmplay2Gui.pipe) || (!createPpipeInvoked && !createPipe()))
         {
-            delete qmplay2Gui.pipe;
-            qmplay2Gui.pipe = nullptr;
 #ifdef QMPLAY2_ALLOW_ONLY_ONE_INSTANCE
             if (settings.getBool("AllowOnlyOneInstance"))
             {
@@ -914,6 +961,7 @@ int main(int argc, char *argv[])
         lastVer.clear();
 
         qmplay2Gui.restartApp = qmplay2Gui.removeSettings = qmplay2Gui.noAutoPlay = false;
+        qmplay2Gui.startInvisible = startInvisible;
         qmplay2Gui.newProfileName.clear();
         new MainWidget(arguments);
         do
@@ -950,7 +998,8 @@ int main(int argc, char *argv[])
         if (qmplay2Gui.noAutoPlay)
             arguments.append({"noplay", QString()});
 
-        delete qmplay2Gui.pipe;
+        qmplay2Gui.pipe.reset();
+        createPpipeInvoked = false;
     } while (qmplay2Gui.restartApp);
 
     qmplay2Gui.deleteIcons();
@@ -960,12 +1009,7 @@ int main(int argc, char *argv[])
 #endif
 
     exitProcedure();
-
-#ifndef Q_OS_WIN
-    if (canDeleteApp)
-#endif
-        delete qApp;
-
+    delete qApp;
 #ifdef Q_OS_HAIKU
     kill(::getpid(), SIGKILL); // FIXME
 #endif
