@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -465,7 +465,17 @@ bool AddThr::add(const QStringList &urls, QTreeWidgetItem *parent, const Functio
                 entry.url = url;
 
                 if (!pLW.dontUpdateAfterAdd) //Don't try to get the real address from extension plugin in this case (no needed for tracks)
+                {
                     Functions::getDataIfHasPluginPrefix(url, &url, &entry.name, nullptr, &ioCtrl, demuxersInfo);
+                    if (Functions::isResourcePlaylist(url))
+                    {
+                        if (add({url}, parent, demuxersInfo, existingEntries, loadList))
+                            added = true;
+                        if (loadList)
+                            break;
+                        continue;
+                    }
+                }
                 IOController<Demuxer> &demuxer = ioCtrl.toRef<Demuxer>();
                 Demuxer::FetchTracks fetchTracks(pLW.dontUpdateAfterAdd);
                 if (Demuxer::create(url, demuxer, &fetchTracks))
@@ -606,7 +616,10 @@ void AddThr::finished()
     pLW.refresh();
     pLW.setItemsResizeToContents(true);
     if (firstItem && ((pLW.selectAfterAdd && pLW.currentItem() != firstItem && pLW.currentItem() == lastItem) || !pLW.currentItem()))
+    {
+        pLW.clearSelection();
         pLW.setCurrentItem(firstItem);
+    }
     pLW.selectAfterAdd = false;
     pLW.setAnimated(true);
     pLW.processItems();
@@ -647,7 +660,6 @@ PlaylistWidget::PlaylistWidget() :
     header()->setSectionResizeMode(0, QHeaderView::Stretch);
     header()->hideSection(1);
     setItemsResizeToContents(true);
-    setIconSize({22, 22});
 
     currentPlaying = nullptr;
     selectAfterAdd = hasHiddenItems = dontUpdateAfterAdd = false;
@@ -988,6 +1000,7 @@ QTreeWidgetItem *PlaylistWidget::newEntry(const Playlist::Entry &entry, QTreeWid
     tWI->setFlags(tWI->flags() &~ Qt::ItemIsDropEnabled);
     tWI->setText(0, entry.name);
     tWI->setData(0, Qt::UserRole, entry.url);
+    tWI->setData(0, Qt::UserRole + 1, QVariant::fromValue(entry.params));
     tWI->setText(2, Functions::timeToStr(entry.length));
     tWI->setData(2, Qt::UserRole, entry.length);
 
@@ -1077,7 +1090,7 @@ void PlaylistWidget::createExtensionsMenu()
             actions = QMPlay2Ext->getActions(entryName, entryLength, url, addressPrefixName, param);
         else
             actions = QMPlay2Ext->getActions(entryName, entryLength, entryUrl);
-        for (QAction *act : qAsConst(actions))
+        for (QAction *act : std::as_const(actions))
         {
             act->setParent(extensions);
             extensions->addAction(act);
@@ -1251,6 +1264,7 @@ void PlaylistWidget::modifyMenu()
     const bool isLocked = (getFlags(currItem) & Playlist::Entry::Locked);
     const bool isItemGroup = isGroup(currItem);
     const bool syncVisible = (isItemGroup && !entryUrl.isEmpty());
+    const auto selectedCount = selectedItems().count();
 
     playlistMenu()->saveGroup->setVisible(isItemGroup);
     playlistMenu()->lock->setText(isLocked ? tr("Un&lock") : tr("&Lock"));
@@ -1262,9 +1276,11 @@ void PlaylistWidget::modifyMenu()
     playlistMenu()->quickSync->setVisible(syncVisible && QFileInfo(QString(entryUrl).remove("file://")).isDir());
     playlistMenu()->renameGroup->setVisible(isItemGroup);
     playlistMenu()->entryProperties->setVisible(currItem);
+    if (currItem)
+        playlistMenu()->entryProperties->setEnabled(selectedCount == 1);
     playlistMenu()->queue->setVisible(currItem && !isItemGroup);
     playlistMenu()->skip->setVisible(currItem && !isItemGroup);
     playlistMenu()->stopAfter->setVisible(currItem && !isItemGroup);
     playlistMenu()->goToPlayback->setVisible(currentPlaying);
-    playlistMenu()->copy->setVisible(selectedItems().count());
+    playlistMenu()->copy->setVisible(selectedCount > 0);
 }
