@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -49,6 +49,7 @@
 #include <QToolButton>
 #include <QGridLayout>
 #include <QMainWindow>
+#include <QScrollBar>
 #include <QBoxLayout>
 #include <QTextCodec>
 #include <QComboBox>
@@ -65,6 +66,7 @@
 #include <KeyBindingsDialog.hpp>
 #include <Appearance.hpp>
 #include <Settings.hpp>
+#include <Version.hpp>
 #include <MenuBar.hpp>
 #include <Module.hpp>
 
@@ -171,6 +173,7 @@ void SettingsWidget::InitSettings()
 #ifdef UPDATES
     QMPSettings.init("AutoUpdates", []{return !QFile::exists(QMPlay2Core.getShareDir() + "noautoupdates");});
 #endif
+    QMPSettings.init("MainWidget/KeepDocksSize", false);
     QMPSettings.init("MainWidget/TabPositionNorth", false);
 #ifdef QMPLAY2_ALLOW_ONLY_ONE_INSTANCE
     QMPSettings.init("AllowOnlyOneInstance", false);
@@ -203,6 +206,8 @@ void SettingsWidget::InitSettings()
     QMPSettings.init("YtDl/CustomPath", QString());
     QMPSettings.init("YtDl/DontAutoUpdate", false);
 # endif
+    QMPSettings.init("YtDl/DefaultQualityEnabled", false);
+    QMPSettings.init("YtDl/DefaultQuality", QString());
 #endif
 
     QMPSettings.init("OpenGL/OnWindow", false);
@@ -270,8 +275,8 @@ void SettingsWidget::InitSettings()
     QMPSettings.init("ApplyToASS/FontsAndSpacing", false);
     QMPSettings.init("ApplyToASS/ApplyToASS", false);
     QMPSettings.init("OSD/Enabled", true);
-    OSDSettingsW::init("Subtitles", 20, 0, 15, 15, 15, 7, 1.0, 0.5, QColor(0xFF, 0xFF, 0xFF, 0xFF), Qt::black, Qt::black, false);
-    OSDSettingsW::init("OSD",       32, 0, 0,  0,  0,  4, 1.5, 1.5, QColor(0xAA, 0xFF, 0x55, 0xFF), Qt::black, Qt::black, false);
+    OSDSettingsW::init("Subtitles", 20, 0, 15, 15, 15, 7, 1.0, 0.5, QColor(0xFF, 0xFF, 0xFF, 0xFF), Qt::black, Qt::black, false, false);
+    OSDSettingsW::init("OSD",       32, 0, 0,  0,  0,  4, 1.5, 1.5, QColor(0xAA, 0xFF, 0x55, 0xFF), Qt::black, Qt::black, false, false);
     DeintSettingsW::init();
     applyProxy();
 }
@@ -443,6 +448,8 @@ SettingsWidget::SettingsWidget(int page, const QString &moduleName, QWidget *vid
         generalSettingsPage->autoUpdatesB = nullptr;
 #endif
 
+        generalSettingsPage->keepDocksSizeB->setChecked(QMPSettings.getBool("MainWidget/KeepDocksSize"));
+
         if (Notifies::hasBoth())
             generalSettingsPage->trayNotifiesDefault->setChecked(QMPSettings.getBool("TrayNotifiesDefault"));
         else
@@ -490,6 +497,9 @@ SettingsWidget::SettingsWidget(int page, const QString &moduleName, QWidget *vid
         generalSettingsPage->customYtDlE->setText(QMPSettings.getString("YtDl/CustomPath"));
         generalSettingsPage->customYtDlB->setIcon(QMPlay2Core.getIconFromTheme("folder-open"));
 
+        generalSettingsPage->dfltYtDlQualCB->setChecked(QMPSettings.getBool("YtDl/DefaultQualityEnabled"));
+        generalSettingsPage->dfltYtDlQualE->setText(QMPSettings.getString("YtDl/DefaultQuality"));
+
         generalSettingsPage->dontUpdateYtDlCB->setChecked(QMPSettings.getBool("YtDl/DontAutoUpdate"));
 
         connect(generalSettingsPage->cookiesFromBrowserCB, &QCheckBox::toggled, this, [this](bool checked) {
@@ -505,9 +515,13 @@ SettingsWidget::SettingsWidget(int page, const QString &moduleName, QWidget *vid
             if (!path.isEmpty())
                 generalSettingsPage->customYtDlE->setText(path);
         });
+        connect(generalSettingsPage->dfltYtDlQualCB, &QCheckBox::toggled, this, [this](bool checked) {
+            generalSettingsPage->dfltYtDlQualE->setEnabled(checked);
+        });
 
         emit generalSettingsPage->cookiesFromBrowserCB->toggled(generalSettingsPage->cookiesFromBrowserCB->isChecked());
         emit generalSettingsPage->customYtDlCB->toggled(generalSettingsPage->customYtDlCB->isChecked());
+        emit generalSettingsPage->dfltYtDlQualCB->toggled(generalSettingsPage->dfltYtDlQualCB->isChecked());
 
         connect(generalSettingsPage->customYtDlCB, &QCheckBox::toggled, this, [this](bool checked) {
             generalSettingsPage->dontUpdateYtDlCB->setChecked(checked);
@@ -1029,7 +1043,7 @@ void SettingsWidget::createRendererSettings()
             bypassCompositor->setEnabled(!noExclusiveFullScreenDevIDs->contains(devices->itemData(idx).toByteArray()));
             hdr->setVisible(QOperatingSystemVersion::current() >= QOperatingSystemVersion::Windows10);
 #else
-            hdr->setVisible(false);
+            hdr->setVisible(QGuiApplication::platformName().contains("wayland"));
 #endif
         });
 
@@ -1210,6 +1224,16 @@ QString SettingsWidget::chooseDir(const QString &currPth)
         if (dirInfo.isDir())
 #endif
         {
+            if (Version::isPortable() && dirInfo.isAbsolute())
+            {
+                const auto appDirPath = QCoreApplication::applicationDirPath();
+                if (auto dirRelative = QDir::cleanPath(dir); dirRelative.startsWith(appDirPath))
+                {
+                    dirRelative.remove(0, appDirPath.size());
+                    dirRelative.prepend(".");
+                    return dirRelative;
+                }
+            }
             return dir;
         }
         QMessageBox::warning(this, QString(), tr("Cannot change the directory"));
@@ -1290,6 +1314,11 @@ void SettingsWidget::apply()
 #ifdef UPDATES
             QMPSettings.set("AutoUpdates", generalSettingsPage->autoUpdatesB->isChecked());
 #endif
+            if (auto checked = generalSettingsPage->keepDocksSizeB->isChecked(); checked != QMPSettings.getBool("MainWidget/KeepDocksSize"))
+            {
+                QMPSettings.set("MainWidget/KeepDocksSize", checked);
+                emit keepDocksSizeChanged(checked);
+            }
             QMPSettings.set("MainWidget/TabPositionNorth", generalSettingsPage->tabsNorths->isChecked());
 #ifdef QMPLAY2_ALLOW_ONLY_ONE_INSTANCE
             QMPSettings.set("AllowOnlyOneInstance", generalSettingsPage->allowOnlyOneInstance->isChecked());
@@ -1318,6 +1347,8 @@ void SettingsWidget::apply()
             QMPSettings.set("YtDl/CookiesFromBrowser", generalSettingsPage->cookiesFromBrowserE->text());
             QMPSettings.set("YtDl/CustomPathEnabled", generalSettingsPage->customYtDlCB->isChecked() && !generalSettingsPage->customYtDlE->text().trimmed().isEmpty());
             QMPSettings.set("YtDl/CustomPath", generalSettingsPage->customYtDlE->text());
+            QMPSettings.set("YtDl/DefaultQualityEnabled", generalSettingsPage->dfltYtDlQualCB->isChecked() && !generalSettingsPage->dfltYtDlQualE->text().simplified().isEmpty());
+            QMPSettings.set("YtDl/DefaultQuality", generalSettingsPage->dfltYtDlQualE->text());
             QMPSettings.set("YtDl/DontAutoUpdate", generalSettingsPage->dontUpdateYtDlCB->isChecked());
 #endif
 
@@ -1342,8 +1373,7 @@ void SettingsWidget::apply()
                 videoWriters += wI->text();
             QMPSettings.set("videoWriters", videoWriters);
 
-            if (initFilters)
-                page6->deintSettingsW->setSoftwareDeintEnabledDisabled();
+            page6->deintSettingsW->setDeintEnabledDisabled();
 
             break;
         }
@@ -1428,7 +1458,9 @@ void SettingsWidget::apply()
                 settingsWidget->saveSettings();
                 settingsWidget->flushSettings();
                 page3->module->setInstances(forceRestartPlayback);
+                const int scroll = page3->scrollA->verticalScrollBar()->value();
                 chModule(page3->listW->currentItem());
+                page3->scrollA->verticalScrollBar()->setValue(scroll);
             }
             break;
         case 4:
