@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2023  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -79,7 +79,7 @@ AudioCD::SettingsWidget *AudioCD::getSettingsWidget()
 
 void AudioCD::add()
 {
-    QWidget *parent = qobject_cast<QWidget *>(sender()->parent());
+    QWidget *parent = QMPlay2Core.getMainWindow();
     QStringList drives = AudioCDDemux::getDevices();
     if (!drives.isEmpty())
     {
