@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -38,6 +38,7 @@ class QPushButton;
 class QGroupBox;
 class QCheckBox;
 class QComboBox;
+class QLineEdit;
 class QSpinBox;
 class Slider;
 
@@ -80,5 +81,10 @@ private:
     QComboBox *eqQualityB;
     QSpinBox *eqSlidersB, *eqMinFreqB, *eqMaxFreqB;
 
+#ifdef USE_AVAUDIOFILTER
+    QGroupBox *m_avAudioFilterB = nullptr;
+    QLineEdit *m_avAudioFilterE = nullptr;
+#endif
+
     QPushButton *defaultB;
 };
