@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -718,7 +718,7 @@ void YouTube::setItags(int qualityIdx)
         AV1_HFR_HIGH_1080p = 699,
         AV1_HFR_HIGH_720p = 698,
 
-        // Live video
+        // Live video (old)
         H264_144p_AAC_48 = 91,
         H264_240p_AAC_48 = 92,
         H264_360p_AAC_128 = 93,
@@ -728,6 +728,20 @@ void YouTube::setItags(int qualityIdx)
         H264_720p60_AAC_128 = 300,
         H264_1080p60_AAC_128 = 301,
 
+        // Live video (new)
+        H264_144p_LIVE = 269,
+        H264_240p_LIVE = 229,
+        H264_360p_LIVE = 230,
+        H264_480p_LIVE = 231,
+        H264_720p_LIVE = 232,
+        H264_1080p_LIVE = 270,
+        H264_720p60_LIVE = 311,
+        H264_1080p60_LIVE = 312,
+
+        // Live video audio (new)
+        AAC_48_Live = 233,
+        AAC_128_Live = 234,
+
         // Audio
         Opus_160 = 251,
         AAC_128 = 140,
@@ -814,6 +828,21 @@ void YouTube::setItags(int qualityIdx)
             qualityPresets[Preset_4320p60] << VP9_4320p60 << qualityPresets[Preset_2160p60];
         }
 
+        // Append live streams
+        {
+            qualityPresets[Preset_480p]  << H264_480p_LIVE << H264_360p_LIVE << H264_240p_LIVE << H264_144p_LIVE;
+            qualityPresets[Preset_720p]  << H264_720p_LIVE << qualityPresets[Preset_480p];
+            qualityPresets[Preset_1080p] << H264_1080p_LIVE << qualityPresets[Preset_720p];
+            qualityPresets[Preset_1440p] << qualityPresets[Preset_1080p];
+            qualityPresets[Preset_2160p] << qualityPresets[Preset_1440p];
+
+            qualityPresets[Preset_720p60]  << H264_720p60_LIVE;
+            qualityPresets[Preset_1080p60] << H264_1080p60_LIVE << qualityPresets[Preset_720p60];
+            qualityPresets[Preset_1440p60] << qualityPresets[Preset_1080p60];
+            qualityPresets[Preset_2160p60] << qualityPresets[Preset_1440p60];
+            qualityPresets[Preset_4320p60] << qualityPresets[Preset_2160p60];
+        }
+
         // Append also non-60 FPS itags to 60 FPS itags
         qualityPresets[Preset_720p60]  << qualityPresets[Preset_720p];
         qualityPresets[Preset_1080p60] << qualityPresets[Preset_1080p];
@@ -823,7 +852,7 @@ void YouTube::setItags(int qualityIdx)
     }
 
     QVector<int> liveQualityPresets[PresetCount];
-    {
+    { // XXX: Is it still needed?
         liveQualityPresets[Preset_480p]  << H264_480p_AAC_128 << H264_360p_AAC_128 << H264_240p_AAC_48 << H264_144p_AAC_48;
         liveQualityPresets[Preset_720p]  << H264_720p_AAC_256 << liveQualityPresets[Preset_480p];
         liveQualityPresets[Preset_1080p] << H264_1080p_AAC_256 << liveQualityPresets[Preset_720p];
@@ -846,7 +875,7 @@ void YouTube::setItags(int qualityIdx)
 
     QMutexLocker locker(&m_itagsMutex);
     m_videoItags = qualityPresets[qualityIdx];
-    m_audioItags = {Opus_160, AAC_128};
+    m_audioItags = {Opus_160, AAC_128, AAC_128_Live, AAC_48_Live};
     m_hlsItags = liveQualityPresets[qualityIdx];
 }
 
@@ -1075,6 +1104,7 @@ void YouTube::setSearchResults(const QJsonObject &jsonObj, bool isContinuation,
             for (const QJsonValue obj : contents)
             {
                 bool radioRenderer = false;
+                bool lockupViewModel = false;
 
                 const auto videoRenderer = obj["videoRenderer"].toObject();
                 const auto playlistRenderer = [&] {
@@ -1084,6 +1114,11 @@ void YouTube::setSearchResults(const QJsonObject &jsonObj, bool isContinuation,
                         r = obj["radioRenderer"].toObject();
                         radioRenderer = !r.isEmpty();
                     }
+                    if (r.isEmpty())
+                    {
+                        r = obj["lockupViewModel"].toObject();
+                        lockupViewModel = !r.isEmpty();
+                    }
                     return r;
                 }();
 
@@ -1104,7 +1139,30 @@ void YouTube::setSearchResults(const QJsonObject &jsonObj, bool isContinuation,
 
                     url = YOUTUBE_URL "/watch?v=" + contentId;
                 }
-                else
+                else if (lockupViewModel)
+                {
+                    QString videoId;
+
+                    title = playlistRenderer["metadata"]["lockupMetadataViewModel"]["title"]["content"].toString();
+                    contentId = playlistRenderer["rendererContext"]["commandContext"]["onTap"]["innertubeCommand"]["watchEndpoint"]["playlistId"].toString();
+                    videoId = playlistRenderer["rendererContext"]["commandContext"]["onTap"]["innertubeCommand"]["watchEndpoint"]["videoId"].toString();
+                    if (title.isEmpty() || contentId.isEmpty() || videoId.isEmpty())
+                        continue;
+
+                    const auto thumbnails = playlistRenderer
+                        ["contentImage"]
+                        ["collectionThumbnailViewModel"]
+                        ["primaryThumbnail"]
+                        ["thumbnailViewModel"]
+                        ["image"]
+                        ["sources"].toArray()
+                    ;
+                    if (!thumbnails.isEmpty())
+                        thumbnail = thumbnails[0]["url"].toString();
+
+                    url = YOUTUBE_URL "/watch?v=" + videoId + "&list=" + contentId;
+                }
+                else // XXX: Is is still possible?
                 {
                     QString videoId;
 
@@ -1186,7 +1244,7 @@ QStringList YouTube::getYouTubeVideo(const QString &param, const QString &url, I
             const auto entry = entryVal.toObject();
             entries += {entry["title"].toString(), "YouTube://{" + entry["url"].toString() + "}" + param, entry["duration"].toDouble(-1.0)};
         }
-        const auto resourceName = QMPlay2Core.writePlaylistResource(YouTubeName "/" + title, entries);
+        const auto resourceName = QMPlay2Core.writePlaylistResource("YouTube://" + title, o["webpage_url"].toString(), entries);
         if (!resourceName.isEmpty())
         {
             return {resourceName, ".pls", title, QString()};
@@ -1288,6 +1346,8 @@ QStringList YouTube::getYouTubeVideo(const QString &param, const QString &url, I
         auto subtitlesForLang = subtitles[lang].toArray();
         if (subtitlesForLang.isEmpty())
             subtitlesForLang = subtitles[QMPlay2Core.getLanguage()].toArray();
+        if (subtitlesForLang.isEmpty())
+            subtitlesForLang = subtitles["en"].toArray();
 
         for (auto &&subtitlesFmtVal : std::as_const(subtitlesForLang))
         {
