@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -44,7 +44,7 @@ class FormatContext
 {
     Q_DECLARE_TR_FUNCTIONS(FormatContext)
 public:
-    FormatContext(bool reconnectNetwork = false);
+    FormatContext(bool reconnectNetwork = false, bool allowExperimental = false);
     ~FormatContext();
 
     bool metadataChanged() const;
@@ -93,7 +93,8 @@ private:
 
     OggHelper *oggHelper;
 
-    bool m_reconnectNetwork;
+    const bool m_reconnectNetwork;
+    const bool m_allowExperimental;
     bool isPaused, fixMkvAss;
     mutable bool isMetadataChanged;
     double lastTime, startTime;
