@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -26,17 +26,24 @@ ColorButton::ColorButton(QWidget *parent) :
 {
     setCursor(Qt::PointingHandCursor);
     setAttribute(Qt::WA_OpaquePaintEvent);
-    connect(this, SIGNAL(clicked()), this, SLOT(openColorDialog()));
+    connect(this, &ColorButton::clicked, this, &ColorButton::openColorDialog);
+}
+
+void ColorButton::setAlphaAllowed(bool alpha)
+{
+    m_alphaChannel = alpha;
 }
 
 void ColorButton::setColor(const QColor &color)
 {
     m_color = color;
-    m_color.setAlpha(255);
-    setToolTip(QString("#%1%2%3")
+    if (!m_alphaChannel)
+        m_color.setAlpha(255);
+    setToolTip(QString("#%1%2%3%4")
                .arg(m_color.red(), 2, 16, QChar('0'))
                .arg(m_color.green(), 2, 16, QChar('0'))
                .arg(m_color.blue(), 2, 16, QChar('0'))
+               .arg(m_alphaChannel ? QStringLiteral("%1").arg(m_color.alpha(), 2, 16, QChar('0')) : QString())
                .toUpper()
     );
     update();
@@ -45,12 +52,19 @@ void ColorButton::setColor(const QColor &color)
 void ColorButton::paintEvent(QPaintEvent *)
 {
     QPainter p(this);
+    if (m_alphaChannel)
+        p.fillRect(rect(), Qt::white);
     p.fillRect(rect(), m_color);
 }
 
 void ColorButton::openColorDialog()
 {
-    const QColor color = QColorDialog::getColor(getColor(), this);
+    const auto color = QColorDialog::getColor(
+        m_color,
+        this,
+        QString(),
+        m_alphaChannel ? QColorDialog::ColorDialogOption::ShowAlphaChannel : QColorDialog::ColorDialogOption()
+    );
     if (color.isValid() && m_color != color)
     {
         setColor(color);
