@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -41,6 +41,8 @@ class BufferPool;
 }
 #endif
 
+class QSize;
+
 class QMPLAY2SHAREDLIB_EXPORT LibASS
 {
 public:
@@ -51,7 +53,7 @@ public:
 
     bool addImgs(ass_image *img, QMPlay2OSD *osd);
 
-    void setWindowSize(int, int);
+    void setWindowSize(const QSize &winSize);
     void setARatio(double);
     void setZoom(double);
     void setFontScale(double);
