@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -677,12 +677,12 @@ QString QMPlay2CoreClass::getDescriptionForUrl(const QString &url)
     return getDataFromHash(url, descriptionsForUrl);
 }
 
-QString QMPlay2CoreClass::writePlaylistResource(const QString &name, const PlaylistEntries &playlistEntries)
+QString QMPlay2CoreClass::writePlaylistResource(const QString &name, const QString &args, const PlaylistEntries &playlistEntries)
 {
     if (playlistEntries.isEmpty())
         return QString();
 
-    const QString resourceName = "QMPlay2://" + name + ".pls";
+    const QString resourceName = "QMPlay2://{" + name + ".pls}" + args;
     if (Playlist::write(playlistEntries, resourceName))
     {
         modResource(resourceName, true);
