@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -188,8 +188,8 @@ public:
         return lang;
     }
 
-    virtual const QWidget *getVideoDock() const = 0;
-    virtual const QWidget *getMainWindow() const = 0;
+    virtual QWidget *getVideoDock() const = 0;
+    virtual QWidget *getMainWindow() const = 0;
 
     void addVideoDeintMethod(QWidget *w); //Needed properties: "text", "module"
     QList<QWidget *> getVideoDeintMethods() const;
@@ -211,7 +211,7 @@ public:
     void addDescriptionForUrl(const QString &url, const QString &description, const bool removeAfterUse = true);
     QString getDescriptionForUrl(const QString &url);
 
-    QString writePlaylistResource(const QString &name, const PlaylistEntries &playlistEntries);
+    QString writePlaylistResource(const QString &name, const QString &args, const PlaylistEntries &playlistEntries);
 
     QString rendererName() const;
     Renderer renderer() const;
