@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -29,6 +29,12 @@ extern "C" {
     #include <libavcodec/avcodec.h>
 }
 
+#if LIBAVUTIL_VERSION_INT >= AV_VERSION_INT(57, 28, 100)
+#   define CODECPAR_NB_CHANNELS ch_layout.nb_channels
+#else
+#   define CODECPAR_NB_CHANNELS channels
+#endif
+
 using QMPlay2Tag = QPair<QString, QString>;
 
 enum QMPlay2Tags
@@ -107,6 +113,8 @@ public:
     bool is_default = true;
     bool must_decode = false;
     bool decode_to_ass = false;
+    bool skip_auto_select = false;
+    bool ts_discont_possible = false;
     AVRational time_base = {1, 10000};
 
     // Video only
