@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -265,12 +265,12 @@ bool Instance::checkFiltersSupported(const shared_ptr<PhysicalDevice> &physicalD
 
 shared_ptr<Instance> Instance::create(bool doObtainPhysicalDevice)
 {
-    auto instance = make_shared<Instance>(Priv());
+    auto instance = make_shared<Instance>();
     instance->init(doObtainPhysicalDevice);
     return instance;
 }
 
-Instance::Instance(Priv)
+Instance::Instance()
     : m_qVulkanInstance(new QVulkanInstance)
 {}
 Instance::~Instance()
@@ -339,6 +339,7 @@ void Instance::init(bool doObtainPhysicalDevice)
         "VK_KHR_wayland_surface",
         "VK_KHR_win32_surface",
         "VK_KHR_xcb_surface",
+        "VK_EXT_swapchain_colorspace",
 #if USE_VALIDATION_LAYER
         VK_EXT_DEBUG_UTILS_EXTENSION_NAME,
 #endif
