@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -83,6 +83,7 @@ public:
         float hue,
         float saturation,
         float sharpness,
+        bool negative,
         AVColorPrimaries colorPrimaries,
         AVColorTransferCharacteristic colorTrc
     );
@@ -168,6 +169,7 @@ private:
     QTimer m_initResourcesTimer;
 
     const bool m_isWayland;
+    const bool m_isXcb;
 
     const bool m_passEventsToParent;
 
@@ -250,6 +252,7 @@ private:
     float m_hue = 0.0f;
     float m_saturation = 1.0f;
     float m_sharpness = 0.0f;
+    bool m_negative = false;
 
     vk::Format m_format = vk::Format::eUndefined;
     Frame m_frame;
