@@ -1,6 +1,6 @@
 /*
     QMPlay2 is a video and audio player.
-    Copyright (C) 2010-2024  Błażej Szczygieł
+    Copyright (C) 2010-2025  Błażej Szczygieł
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU Lesser General Public License as published
@@ -18,7 +18,6 @@
 
 #include <Settings.hpp>
 
-#include "../../qmvk/PhysicalDevice.hpp"
 #include "../../qmvk/Device.hpp"
 #include "../../qmvk/Queue.hpp"
 #include "../../qmvk/ComputePipeline.hpp"
@@ -40,6 +39,7 @@ struct alignas(16) YadifPushConstants
 {
     int parity;
     int filterParity;
+    int height;
 };
 
 YadifDeint::YadifDeint(const shared_ptr<HWInterop> &hwInterop)
@@ -168,6 +168,7 @@ bool YadifDeint::filter(QQueue<Frame> &framesQueue)
                 auto yadifPushConstants = m.computes[p][f]->pushConstants<YadifPushConstants>();
                 yadifPushConstants->parity = m_secondFrame == tff;
                 yadifPushConstants->filterParity = yadifPushConstants->parity ^ int(tff);
+                yadifPushConstants->height = destImage->size(p).height;
 
                 m.computes[p][f]->setCustomSpecializationData({
                     m_spatialCheck,
@@ -256,7 +257,6 @@ bool YadifDeint::ensureResources()
             Instance::readShader("yadif.comp")
         );
 
-        const auto vendorID = m.device->physicalDevice()->properties().vendorID;
         const int nf = (m_deintFlags & DoubleFramerate) ? 2 : 1;
 
         for (auto &&computeF : m.computes)
@@ -271,19 +271,7 @@ bool YadifDeint::ensureResources()
                     sizeof(YadifPushConstants)
                 );
 
-                switch (vendorID)
-                {
-                    case 0x8086: // Intel
-                        if (!compute->setLocalWorkgroupSize(vk::Extent2D(16, 32)))
-                            compute->setLocalWorkgroupSize(vk::Extent2D(16, 16));
-                        break;
-                    case 0x1002: // AMD
-                        compute->setLocalWorkgroupSize(vk::Extent2D(64, 8));
-                        break;
-                    case 0x10de: // NVIDIA
-                        compute->setLocalWorkgroupSize(vk::Extent2D(128, 8));
-                        break;
-                }
+                compute->setLocalWorkgroupSize(vk::Extent2D(64, 1));
             }
         }
 
