@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2024 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
@@ -23,21 +23,14 @@ class Device;
 
 class QMVK_EXPORT AbstractInstance : public vk::Instance, public enable_shared_from_this<AbstractInstance>
 {
-protected:
-    // Functions must be called only once and are not thread-safe
-    static PFN_vkGetInstanceProcAddr loadVulkanLibrary(const string &vulkanLibrary = {});
-    static void initDispatchLoaderDynamic(PFN_vkGetInstanceProcAddr vkGetInstanceProcAddr, vk::Instance instance = {});
-
-public:
-    static const vk::DispatchLoaderDynamic &getDispatchLoaderDynamic();
-
-    static bool isVk10();
-    static uint32_t version();
-
 protected:
     AbstractInstance() = default;
     virtual ~AbstractInstance() = default;
 
+    PFN_vkGetInstanceProcAddr loadVulkanLibrary(const string &vulkanLibrary = {});
+    PFN_vkGetInstanceProcAddr setVulkanLibrary(const shared_ptr<vk::DynamicLoader> &dl);
+    void initDispatchLoaderDynamic(PFN_vkGetInstanceProcAddr vkGetInstanceProcAddr, vk::Instance instance = {});
+
     unordered_set<string> getAllInstanceLayers();
 
     void fetchAllExtensions();
@@ -46,10 +39,17 @@ protected:
     );
 
 public:
+    inline shared_ptr<vk::DynamicLoader> getDl() const;
+
+    inline const vk::DispatchLoaderDynamic &dld() const;
+
+    inline bool isVk10();
+    uint32_t version();
+
     inline const auto &enabledExtensions() const;
     inline bool checkExtension(const char *extension) const;
 
-    vector<shared_ptr<PhysicalDevice>> enumeratePhysicalDevices(bool compatibleOnly);
+    vector<shared_ptr<PhysicalDevice>> enumeratePhysicalDevices(bool compatibleOnly, bool sort = true);
 
     shared_ptr<Device> createDevice(
         const shared_ptr<PhysicalDevice> &physicalDevice,
@@ -68,12 +68,29 @@ protected:
     unordered_set<string> m_extensions;
 
 private:
+    shared_ptr<vk::DynamicLoader> m_dl;
+    vk::DispatchLoaderDynamic m_dld;
     weak_ptr<Device> m_deviceWeak;
     mutable mutex m_deviceMutex;
 };
 
 /* Inline implementation */
 
+shared_ptr<vk::DynamicLoader> AbstractInstance::getDl() const
+{
+    return m_dl;
+}
+
+const vk::DispatchLoaderDynamic &AbstractInstance::dld() const
+{
+    return m_dld;
+}
+
+bool AbstractInstance::isVk10()
+{
+    return (dld().vkEnumerateInstanceVersion == nullptr);
+}
+
 const auto &AbstractInstance::enabledExtensions() const
 {
     return m_extensions;
