@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2024 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
@@ -24,7 +24,6 @@ class Queue;
 
 class QMVK_EXPORT CommandBuffer : public vk::CommandBuffer
 {
-    struct Priv {};
     struct StoredData;
 
 public:
@@ -38,8 +37,7 @@ public:
 
 public:
     CommandBuffer(
-        const shared_ptr<Queue> &queue,
-        Priv
+        const shared_ptr<Queue> &queue
     );
     ~CommandBuffer();
 
