@@ -1,7 +1,7 @@
 // SPDX-License-Identifier: MIT
 /*
    QmVk - simple Vulkan library created for QMPlay2
-   Copyright (C) 2020-2023 Błażej Szczygieł
+   Copyright (C) 2020-2025 Błażej Szczygieł
 */
 
 #pragma once
@@ -10,6 +10,8 @@
 
 #include <vulkan/vulkan.hpp>
 
+#include <memory>
+
 namespace QmVk {
 
 using namespace std;
@@ -19,8 +21,6 @@ class Device;
 
 class QMVK_EXPORT DescriptorPool
 {
-    struct Priv {};
-
 public:
     static shared_ptr<DescriptorPool> create(
         const shared_ptr<DescriptorSetLayout> &descriptorSetLayout,
@@ -30,8 +30,7 @@ public:
 public:
     DescriptorPool(
         const shared_ptr<DescriptorSetLayout> &descriptorSetLayout,
-        uint32_t max,
-        Priv
+        uint32_t max
     );
     ~DescriptorPool();
 
